@@ -34,7 +34,7 @@ using namespace ZenLib;
 
 //---------------------------------------------------------------------------
 Preferences* Prefs=new Preferences;
-int ExplorerShell_Edit  (const AnsiString &Name, bool ShellExtension, bool &IsChanged, TRegistry* Reg);
+int ExplorerShell_Edit  (const AnsiString &Name, bool ShellExtension, bool &IsChanged);
 //---------------------------------------------------------------------------
 
 //***************************************************************************
@@ -70,6 +70,10 @@ Preferences::Preferences()
     Sponsored=false;
     SponsorMessage=__T("");
     SponsorUrl=__T("");
+
+    //Plugins
+    GraphPluginURL=__T("");
+    GraphPluginVersion=__T("");
 }
 
 //***************************************************************************
@@ -212,6 +216,12 @@ int Preferences::Config_Load()
         SponsorUrl.Write(Saved);
     }
 
+    if (!Config(__T("GraphPluginURL")).empty())
+        GraphPluginURL=Config(__T("GraphPluginURL"));
+
+    if (!Config(__T("GraphPluginVersion")).empty())
+        GraphPluginVersion=Config(__T("GraphPluginVersion"));
+
     delete Reg_User; Reg_User=NULL;
 
     return Retour;
@@ -495,6 +505,20 @@ void __fastcall ThreadInternetCheck::Execute()
     }
     Prefs->Config_Save();
 
+    //Plugins
+    Ztring GraphPluginURL=Download(__T("GraphPluginURL"));
+    if (!GraphPluginURL.empty())
+    {
+        Prefs->Config(__T("GraphPluginURL"))=GraphPluginURL;
+        Prefs->Config_Save();
+    }
+
+    Ztring GraphPluginVersion=Download(__T("GraphPluginVersion"));
+    if (!GraphPluginVersion.empty())
+    {
+        Prefs->Config(__T("GraphPluginVersion"))=GraphPluginVersion;
+        Prefs->Config_Save();
+    }
     //Chargement de pages
     ZtringListList Pages=Download.SubSheet(__T("Url"));
     for (size_t Pos=0; Pos<Pages.size(); Pos++)
@@ -530,7 +554,7 @@ int Preferences::ExplorerShell()
     List=__T(
         ".264;H264File\r\n"
         ".3g2;mpeg4File\r\n"
-        ".3ga;mpeg4File\r\n"    
+        ".3ga;mpeg4File\r\n"
         ".3gp;mpeg4File\r\n"
         ".3gpa;mpeg4File\r\n"
         ".3gpp;mpeg4File\r\n"
@@ -565,8 +589,8 @@ int Preferences::ExplorerShell()
         ".dvr-ms;DVRMSFile\r\n"
         ".eac3;EAC3File\r\n"
         ".evo;EVOFile\r\n"
-        ".f4a;mpeg4File\r\n"  
-        ".f4b;mpeg4File\r\n" 
+        ".f4a;mpeg4File\r\n"
+        ".f4b;mpeg4File\r\n"
         ".f4v;mpeg4File\r\n"
         ".fla;FLACFile\r\n"
         ".flc;FLICFile\r\n"
@@ -723,7 +747,8 @@ int Preferences::ExplorerShell()
             if (Reg->OpenKey(List(I1, 0).c_str(), false))
             {
                 //test if extension is known
-                AnsiString Player=Reg->ReadString(__T(""));
+                AnsiString Player;
+                try {Player=Reg->ReadString("");} catch (...){}
                 Reg->CloseKey();
 
                 //Test if old Media Info shell extension is known
@@ -751,7 +776,8 @@ int Preferences::ExplorerShell()
             if (Reg_User->OpenKey((Ztring(__T("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\FileExts\\"))+List(I1, 0)+__T("\\UserChoice")).c_str(), false))
             {
                 //test if extension is known
-                AnsiString Player=Reg_User->ReadString("Progid");
+                AnsiString Player;
+                try {Player=Reg_User->ReadString("Progid");} catch (...){}
                 Reg_User->CloseKey();
 
                 //Test if MediaInfo shell extension is known
@@ -765,10 +791,10 @@ int Preferences::ExplorerShell()
                 }
             }
         }
-        ExplorerShell_Edit("SystemFileAssociations\\audio", 0, IsChanged, Reg);
-        ExplorerShell_Edit("SystemFileAssociations\\Directory.Audio", 0, IsChanged, Reg);
-        ExplorerShell_Edit("SystemFileAssociations\\Directory.Video", 0, IsChanged, Reg);
-        ExplorerShell_Edit("SystemFileAssociations\\video", 0, IsChanged, Reg);
+        ExplorerShell_Edit("SystemFileAssociations\\audio", 0, IsChanged);
+        ExplorerShell_Edit("SystemFileAssociations\\Directory.Audio", 0, IsChanged);
+        ExplorerShell_Edit("SystemFileAssociations\\Directory.Video", 0, IsChanged);
+        ExplorerShell_Edit("SystemFileAssociations\\video", 0, IsChanged);
 
         //Adding/removing to SystemFileAssociations
         int32s ShellExtension=Config.Read(__T("ShellExtension")).To_int32s();
@@ -776,9 +802,9 @@ int Preferences::ExplorerShell()
         {
             //Remove shell ext except "Folder"
             if (List(I1, 0)!=__T("Folder"))
-                ExplorerShell_Edit((__T("Software\\Classes\\SystemFileAssociations\\")+List(I1, 0)).c_str(), ShellExtension, IsChanged, Reg_User);
+                ExplorerShell_Edit((__T("Software\\Classes\\SystemFileAssociations\\")+List(I1, 0)).c_str(), ShellExtension, IsChanged);
         }
-        ExplorerShell_Edit("Software\\Classes\\Directory", Config.Read(__T("ShellExtension_Folder")).To_int32s(), IsChanged, Reg_User);
+        ExplorerShell_Edit("Software\\Classes\\Directory", Config.Read(__T("ShellExtension_Folder")).To_int32s(), IsChanged);
     }
     else
     {
@@ -788,11 +814,12 @@ int Preferences::ExplorerShell()
             if (List(I1, 0)==__T("Folder"))
                 ShellExtension=Config.Read(__T("ShellExtension_Folder")).To_int32s();
 
-            //Open (or create) a extension. Create only if Sheel extension is wanted
+            //Open (or create) a extension. Create only if Shell extension is wanted
             if (Reg->OpenKey(List(I1, 0).c_str(), ShellExtension))
             {
                 //test if extension is known
-                AnsiString Player=Reg->ReadString(__T(""));
+                AnsiString Player;
+                try {Player=Reg->ReadString("");} catch (...){}
                 if (Player=="")
                 {
                     //extension not known, will use our default
@@ -825,7 +852,8 @@ int Preferences::ExplorerShell()
                     {
                         //test if good writing
                         AnsiString ShellExtensionToWtrite="\"" + Application->ExeName +"\" \"%1\"";
-                        AnsiString ShellExtension=Reg->ReadString(__T("")).c_str();
+                        AnsiString ShellExtension;
+                        try {ShellExtension=Reg->ReadString("");} catch (...){}
                         if (ShellExtension!=ShellExtensionToWtrite)
                         {
                             //This is not the good shell extension, writing new one
@@ -863,7 +891,8 @@ int Preferences::ExplorerShell()
             if (Reg_User->OpenKey((Ztring(__T("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\FileExts\\"))+List(I1, 0)+__T("\\UserChoice")).c_str(), false))
             {
                 //test if extension is known
-                AnsiString Player=Reg_User->ReadString("Progid");
+                AnsiString Player;
+                try {Player=Reg_User->ReadString("Progid");} catch (...){}
                 Reg_User->CloseKey();
 
                 //Test if MediaInfo shell extension is known
@@ -876,7 +905,8 @@ int Preferences::ExplorerShell()
                         {
                             //test if good writing
                             AnsiString ShellExtensionToWtrite="\"" + Application->ExeName +"\" \"%1\"";
-                            AnsiString ShellExtension=Reg->ReadString(__T("")).c_str();
+                            AnsiString ShellExtension;
+                            try {ShellExtension=Reg->ReadString("");} catch (...){}
                             if (ShellExtension!=ShellExtensionToWtrite)
                             {
                                 //This is not the good shell extension, writing new one
@@ -951,7 +981,7 @@ void Dynamic_Free()
 }
 
 //---------------------------------------------------------------------------
-int ExplorerShell_Edit(const AnsiString &Player, bool ShellExtension, bool &IsChanged, TRegistry* Reg)
+int ExplorerShell_Edit(const AnsiString &Player, bool ShellExtension, bool &IsChanged)
 {
     ::HKEY Key;
     LONG WINAPI Result;
@@ -989,9 +1019,9 @@ int ExplorerShell_Edit(const AnsiString &Player, bool ShellExtension, bool &IsCh
                     RegCloseKey(Key);
                     return 0;
                 }
-                RegCloseKey(Key);
                 IsChanged=true;
             }
+            RegCloseKey(Key);
         }
         else// if (Player!=__T("Folder"))
         {
@@ -1012,10 +1042,8 @@ int ExplorerShell_Edit(const AnsiString &Player, bool ShellExtension, bool &IsCh
                 return 0;
             }
             Result=RegDeleteKey(HKEY_CURRENT_USER, Ztring().From_Local((Player+"\\Shell").c_str()).c_str()); //Clear it if empty
-
             IsChanged=true;
         }
-        Reg->CloseKey();
     }
     else
     {
@@ -1071,9 +1099,9 @@ int ExplorerShell_Edit(const AnsiString &Player, bool ShellExtension, bool &IsCh
                     RegCloseKey(Key);
                     return 0;
                 }
-                RegCloseKey(Key);
                 IsChanged=true;
             }
+            RegCloseKey(Key);
         }
         else// if (Player!=__T("Folder"))
         {
@@ -1090,7 +1118,6 @@ int ExplorerShell_Edit(const AnsiString &Player, bool ShellExtension, bool &IsCh
 
             IsChanged=true;
         }
-        Reg->CloseKey();
     }
     else
     {
@@ -1443,5 +1470,3 @@ ZenLib::Ztring &Preferences::Translate(ZenLib::Ztring Name)
     else
         return Details[Prefs_Language](Pos)(1);
 }
-
-
