@@ -21,14 +21,20 @@ class AboutActivity : AppCompatActivity() {
 
         supportActionBar?.setDisplayHomeAsUpEnabled(true)
 
-        about_textview.text = about_textview.text.toString()
-                .replace("MI_VERSION", getString(R.string.app_version))
-                .replace("MIL_VERSION", Core.version)
+        about_about_textview.text = about_about_textview.text.toString()
+                .replace("%MI_VERSION%", getString(R.string.app_version))
+                .replace("%MIL_VERSION%", Core.version)
 
         website_btn.setOnClickListener {
             val intent = Intent(Intent.ACTION_VIEW)
             intent.data = Uri.parse(getString(R.string.website_url))
             startActivity(intent)
         }
+
+        email_btn.setOnClickListener {
+            val intent = Intent(Intent.ACTION_VIEW)
+            intent.data = Uri.parse(getString(R.string.email_url))
+            startActivity(intent)
+        }
     }
 }
\ No newline at end of file
