@@ -16,9 +16,20 @@ typedef enum {
     VIEW_TEXT,
     VIEW_HTML,
     VIEW_XML,
-    VIEW_MPEG7,
+    VIEW_JSON,
     VIEW_PBCORE,
     VIEW_PBCORE2,
+    VIEW_MPEG7,
+    VIEW_EBUCORE_1_5,
+    VIEW_EBUCORE_1_6,
+    VIEW_EBUCORE_1_8_ps,
+    VIEW_EBUCORE_1_8_sp,
+    VIEW_EBUCORE_1_8_ps_JSON,
+    VIEW_EBUCORE_1_8_sp_JSON,
+    VIEW_FIMS_1_1,
+    VIEW_FIMS_1_2,
+    VIEW_FIMS_1_3,
+    VIEW_NISO_Z39_87,
     VIEW_CUSTOM,
     NB_VIEW
 } ViewMode;
