@@ -173,6 +173,12 @@ void TExportF::Name_Adapt()
         SaveDialog1->DefaultExt=__T("xml");
         SaveDialog1->Filter=__T("XML File|*.xml");
     }
+    else if (Export->ActivePage==Export_Graph_Svg)
+    {
+        FN.Extension_Set(__T("svg"));
+        SaveDialog1->DefaultExt=__T("svg");
+        SaveDialog1->Filter=__T("SVG File|*.svg");
+    }
     else if (Export->ActivePage==Export_Custom)
     {
         if (Prefs->Details[Prefs_Custom](Stream_Max+2, 1).size()>0 && Prefs->Details[Prefs_Custom](Stream_Max+2, 1)[0]==__T('<')) //test if HTML
@@ -237,6 +243,8 @@ int TExportF::Run(MediaInfoNameSpace::MediaInfoList &MI, ZenLib::Ztring DefaultF
         Export->ActivePage=Export_FIMS_1_3;
     else if (Info==__T("NISO_Z39.87"))
         Export->ActivePage=Export_NISO_Z39_87;
+    else if (Info==__T("Graph_Svg"))
+        Export->ActivePage=Export_Graph_Svg;
     else if (Info==__T("reVTMD"))
         Export->ActivePage=Export_reVTMD;
 
@@ -705,7 +713,7 @@ void TExportF::Export_Run()
     else if (Export->ActivePage==Export_NISO_Z39_87)
     {
         ToExport->Option_Static(__T("Inform"), __T("NISO_Z39_87"));
-        if (Export_reVTMD_SideCar->Checked)
+        if (Export_NISO_Z39_87_SideCar->Checked)
         {
             for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
             {
@@ -718,6 +726,22 @@ void TExportF::Export_Run()
         }
         Text=ToExport->Inform().c_str();
     }
+    else if (Export->ActivePage==Export_Graph_Svg)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("Graph_Svg"));
+        if (Export_Graph_Svg_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".Graph.svg"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
     else if (Export->ActivePage==Export_Custom)
     {
         ToExport->Option_Static(__T("Inform"), Prefs->Details[Prefs_Custom].Read());
@@ -870,6 +894,13 @@ void __fastcall TExportF::ExportChange(TObject *Sender)
         File_Append->Visible=false;
         Name_Choose->Visible=Export_NISO_Z39_87_SideCar->Checked?false:true;;
     }
+    else if (Export->ActivePage==Export_Graph_Svg)
+    {
+        Export_Graph_Svg_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_Graph_Svg_SideCar->Checked?false:true;;
+    }
     else
     {
         File_Append->Visible=true;
@@ -1019,6 +1050,12 @@ void __fastcall TExportF::Export_NISO_Z39_87_SideCarClick(TObject *Sender)
 }
 //---------------------------------------------------------------------------
 
+void __fastcall TExportF::Export_Graph_Svg_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_Graph_Svg_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
 void TExportF::GUI_Configure()
 {
     //Translation
