@@ -55,6 +55,7 @@ __published:    // IDE-managed Components
     TTabSheet *Export_FIMS_1_3;
     TTabSheet *Export_reVTMD;
     TTabSheet *Export_NISO_Z39_87;
+    TTabSheet *Export_Graph_Svg;
     TTabSheet *Export_Custom;
     TGroupBox *Name_Choose;
     TEdit *Name;
@@ -108,6 +109,7 @@ __published:    // IDE-managed Components
     TCheckBox *Export_FIMS_1_3_SideCar;
     TCheckBox *Export_reVTMD_SideCar;
     TCheckBox *Export_NISO_Z39_87_SideCar;
+    TCheckBox *Export_Graph_Svg_SideCar;
     void __fastcall Name_FileSelectClick(TObject *Sender);
     void __fastcall ExportChange(TObject *Sender);
     void __fastcall OKClick(TObject *Sender);
@@ -131,6 +133,7 @@ __published:    // IDE-managed Components
     void __fastcall Export_FIMS_1_2_SideCarClick(TObject *Sender);
     void __fastcall Export_FIMS_1_3_SideCarClick(TObject *Sender);
     void __fastcall Export_NISO_Z39_87_SideCarClick(TObject *Sender);
+    void __fastcall Export_Graph_Svg_SideCarClick(TObject *Sender);
 
 private:    // User declarations
     void Name_Adapt();
