@@ -196,6 +196,7 @@ __published:    // IDE-managed Components
     TMenuItem *M_Sponsor;
     TMenuItem *M_View_reVTMD;
     TMenuItem *M_View_NISO_Z39_87;
+    TMenuItem *M_View_Graph_Svg;
     TMenuItem *ToolBar_View_XML;
     TMenuItem *ToolBar_View_JSON;
     TMenuItem *ToolBar_View_MPEG7;
@@ -212,6 +213,7 @@ __published:    // IDE-managed Components
     TMenuItem *ToolBar_View_FIMS_1_3;
     TMenuItem *ToolBar_View_reVTMD;
     TMenuItem *ToolBar_View_NISO_Z39_87;
+    TMenuItem *ToolBar_View_Graph_Svg;
     TMenuItem *M_Debug_FullParsing;
     void __fastcall FormResize(TObject *Sender);
     void __fastcall M_Help_AboutClick(TObject *Sender);
@@ -283,6 +285,7 @@ __published:    // IDE-managed Components
     void __fastcall M_SponsorClick(TObject *Sender);
     void __fastcall M_View_reVTMDClick(TObject *Sender);
     void __fastcall M_View_NISO_Z39_87Click(TObject *Sender);
+    void __fastcall M_View_Graph_SvgClick(TObject *Sender);
     void __fastcall M_Debug_FullParsingClick(TObject *Sender);
 private:    // User declarations
 public:        // User declarations
